# Spatial tensors

## Spatial image

```{eval-rst}
.. automodule:: deepali.data.image
    :noindex:
```

```{eval-rst}
.. autoapisummary::

    deepali.data.image.Image
    deepali.data.image.ImageBatch

```

## Spatial vector field

```{eval-rst}
.. automodule:: deepali.data.flow
    :noindex:
```

```{eval-rst}
.. autoapisummary::

    deepali.data.flow.FlowField
    deepali.data.flow.FlowFields

```
